@@ -90,7 +90,7 @@ your crate, add it as a dependency inside [*Cargo.toml*]:
 
 ```toml
 [dependencies]
-az = "1.1"
+az = "1.2"
 ```
 
 The crate requires rustc version 1.31.0 or later.
@@ -119,7 +119,7 @@ additional terms or conditions.
 */
 #![no_std]
 #![warn(missing_docs)]
-#![doc(html_root_url = "https://docs.rs/az/~1.1")]
+#![doc(html_root_url = "https://docs.rs/az/~1.2")]
 #![doc(test(attr(deny(warnings))))]
 #![cfg_attr(feature = "fail-on-warnings", deny(warnings))]
 
@@ -303,6 +303,237 @@ pub trait UnwrappedCast<Dst> {
 /**
 Used to cast values.
 
+This trait enables trait constraints for casting in the opposite direction to
+[`Cast`].
+
+# Examples
+
+```rust
+use az::CastFrom;
+trait Tr {
+    type Assoc: CastFrom<u8>;
+    fn assoc_from_u8(a: u8) -> Self::Assoc {
+        CastFrom::cast_from(a)
+    }
+}
+impl Tr for () {
+    type Assoc = i8;
+}
+assert_eq!(<() as Tr>::assoc_from_u8(5u8), 5i8);
+```
+*/
+pub trait CastFrom<Src> {
+    /// Casts the value.
+    fn cast_from(src: Src) -> Self;
+}
+
+impl<Src: Cast<Dst>, Dst> CastFrom<Src> for Dst {
+    #[inline]
+    #[cfg_attr(track_caller, track_caller)]
+    fn cast_from(src: Src) -> Self {
+        src.cast()
+    }
+}
+
+/**
+Used for checked casts.
+
+This trait enables trait constraints for casting in the opposite direction to
+[`CheckedCast`].
+
+# Examples
+
+```rust
+use az::CheckedCastFrom;
+trait Tr {
+    type Assoc: CheckedCastFrom<u8>;
+    fn checked_assoc_from_u8(a: u8) -> Option<Self::Assoc> {
+        CheckedCastFrom::checked_cast_from(a)
+    }
+}
+impl Tr for () {
+    type Assoc = i8;
+}
+assert_eq!(<() as Tr>::checked_assoc_from_u8(5u8), Some(5i8));
+assert_eq!(<() as Tr>::checked_assoc_from_u8(255u8), None);
+```
+*/
+pub trait CheckedCastFrom<Src>: Sized {
+    /// Casts the value.
+    fn checked_cast_from(src: Src) -> Option<Self>;
+}
+
+impl<Src: CheckedCast<Dst>, Dst> CheckedCastFrom<Src> for Dst {
+    #[inline]
+    #[cfg_attr(track_caller, track_caller)]
+    fn checked_cast_from(src: Src) -> Option<Self> {
+        src.checked_cast()
+    }
+}
+
+/**
+Used to cast, saturating if the value does not fit.
+
+This trait enables trait constraints for casting in the opposite direction to
+[`SaturatingCast`].
+
+# Examples
+
+```rust
+use az::SaturatingCastFrom;
+trait Tr {
+    type Assoc: SaturatingCastFrom<u8>;
+    fn saturating_assoc_from_u8(a: u8) -> Self::Assoc {
+        SaturatingCastFrom::saturating_cast_from(a)
+    }
+}
+impl Tr for () {
+    type Assoc = i8;
+}
+assert_eq!(<() as Tr>::saturating_assoc_from_u8(5u8), 5i8);
+assert_eq!(<() as Tr>::saturating_assoc_from_u8(255u8), 127i8);
+```
+*/
+pub trait SaturatingCastFrom<Src> {
+    /// Casts the value.
+    fn saturating_cast_from(src: Src) -> Self;
+}
+
+impl<Src: SaturatingCast<Dst>, Dst> SaturatingCastFrom<Src> for Dst {
+    #[inline]
+    #[cfg_attr(track_caller, track_caller)]
+    fn saturating_cast_from(src: Src) -> Self {
+        src.saturating_cast()
+    }
+}
+
+/**
+Wrapping cast.
+
+This trait enables trait constraints for casting in the opposite direction to
+[`WrappingCast`].
+
+# Examples
+
+```rust
+use az::WrappingCastFrom;
+trait Tr {
+    type Assoc: WrappingCastFrom<u8>;
+    fn wrapping_assoc_from_u8(a: u8) -> Self::Assoc {
+        WrappingCastFrom::wrapping_cast_from(a)
+    }
+}
+impl Tr for () {
+    type Assoc = i8;
+}
+assert_eq!(<() as Tr>::wrapping_assoc_from_u8(5u8), 5i8);
+assert_eq!(<() as Tr>::wrapping_assoc_from_u8(255u8), -1i8);
+```
+*/
+pub trait WrappingCastFrom<Src> {
+    /// WrappingCasts the value.
+    fn wrapping_cast_from(src: Src) -> Self;
+}
+
+impl<Src: WrappingCast<Dst>, Dst> WrappingCastFrom<Src> for Dst {
+    #[inline]
+    #[cfg_attr(track_caller, track_caller)]
+    fn wrapping_cast_from(src: Src) -> Self {
+        src.wrapping_cast()
+    }
+}
+
+/**
+Used for overflowing casts.
+
+This trait enables trait constraints for casting in the opposite direction to
+[`OverflowingCast`].
+
+# Examples
+
+```rust
+use az::OverflowingCastFrom;
+trait Tr {
+    type Assoc: OverflowingCastFrom<u8>;
+    fn overflowing_assoc_from_u8(a: u8) -> (Self::Assoc, bool) {
+        OverflowingCastFrom::overflowing_cast_from(a)
+    }
+}
+impl Tr for () {
+    type Assoc = i8;
+}
+assert_eq!(<() as Tr>::overflowing_assoc_from_u8(5u8), (5i8, false));
+assert_eq!(<() as Tr>::overflowing_assoc_from_u8(255u8), (-1i8, true));
+```
+*/
+pub trait OverflowingCastFrom<Src>: Sized {
+    /// OverflowingCasts the value.
+    fn overflowing_cast_from(src: Src) -> (Self, bool);
+}
+
+impl<Src: OverflowingCast<Dst>, Dst> OverflowingCastFrom<Src> for Dst {
+    #[inline]
+    #[cfg_attr(track_caller, track_caller)]
+    fn overflowing_cast_from(src: Src) -> (Self, bool) {
+        src.overflowing_cast()
+    }
+}
+
+/**
+Used to cast values, panicking if the value does not fit.
+
+This trait enables trait constraints for casting in the opposite direction to
+[`UnwrappedCast`].
+
+# Examples
+
+```rust
+use az::UnwrappedCastFrom;
+trait Tr {
+    type Assoc: UnwrappedCastFrom<u8>;
+    fn unwrapped_assoc_from_u8(a: u8) -> Self::Assoc {
+        UnwrappedCastFrom::unwrapped_cast_from(a)
+    }
+}
+impl Tr for () {
+    type Assoc = i8;
+}
+assert_eq!(<() as Tr>::unwrapped_assoc_from_u8(5u8), 5i8);
+```
+
+The following assertion would panic because of overflow.
+
+```rust, should_panic
+# use az::UnwrappedCastFrom;
+# trait Tr {
+#     type Assoc: UnwrappedCastFrom<u8>;
+#     fn unwrapped_assoc_from_u8(a: u8) -> Self::Assoc {
+#         UnwrappedCastFrom::unwrapped_cast_from(a)
+#     }
+# }
+# impl Tr for () {
+#     type Assoc = i8;
+# }
+let _overflow = <() as Tr>::unwrapped_assoc_from_u8(255u8);
+```
+
+*/
+pub trait UnwrappedCastFrom<Src> {
+    /// UnwrappedCasts the value.
+    fn unwrapped_cast_from(src: Src) -> Self;
+}
+
+impl<Src: UnwrappedCast<Dst>, Dst> UnwrappedCastFrom<Src> for Dst {
+    #[inline]
+    #[cfg_attr(track_caller, track_caller)]
+    fn unwrapped_cast_from(src: Src) -> Self {
+        src.unwrapped_cast()
+    }
+}
+
+/**
+Used to cast values.
+
 This is a convenience trait to enable writing
 <code>src.[az][`Az::az`]::&lt;Dst&gt;()</code>. This would not work with
 the <code>[Cast][`Cast`]::[cast][`Cast::cast`]</code> method because
